==> shopper_0.5.tar.gz: shopper-0.5/src/ui/LabelEntry.h <==
/* Shopper
 * Copyright (C) 2008 David Greaves
 *
 * This software is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */
#ifndef LABELENTRY_H
#define LABELENTRY_H

#include "shopper.h"           // automake, i8n, gettext
#include <QString>
#include <QLabel>
#include <QLineEdit>
#include <QHBoxLayout>
#include <QMouseEvent>

namespace Shopper
{
	// SLabel a label that emits pressed() when clicked
	class SLabel: public QLabel
	{
		Q_OBJECT;			
	public:
		SLabel(QWidget * parent = 0, Qt::WindowFlags f = 0 );
		SLabel ( const QString & text, QWidget * parent = 0, Qt::WindowFlags f = 0 );
		void mouseReleaseEvent ( QMouseEvent * event );
		virtual void setVisible(bool vis);
	signals:
		void pressed();
	};
		
// LabelEntry - a label that turns into a textbox when clicked
	class LabelEntry : public QWidget
	{
		Q_OBJECT;			
	public:
		LabelEntry(QWidget *parent = 0);
		LabelEntry(const QString & label, QWidget *parent = 0);
	private:
		void init();  // real constructor
	public:
		QString getText();
		void setAlignment ( Qt::Alignment al );
		void setText ( const QString & d);
		virtual void setVisible(bool vis);
		void setFrameStyle(int i);
		void setSizePolicy(QSizePolicy::Policy h, QSizePolicy::Policy v);
		void setSizePolicy(QSizePolicy p);

	protected:
		QString       data;
		SLabel        *label;
		QLineEdit     *entry;
		QHBoxLayout   layout;

	public slots:
		void label_clicked();
		void entry_finished();
	signals:
		void changed();
	};
}
#endif // LABELENTRY_H

==> shopper_0.5.5.tar.gz: shopper-0.5.5/src/ui/LabelEntry.h <==
/* Shopper
 * Copyright (C) 2008 David Greaves
 *
 * This software is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */
#ifndef LABELENTRY_H
#define LABELENTRY_H

#include "shopper.h"           // automake, i8n, gettext
#include <QString>
#include <QLabel>
#include <QLineEdit>
#include <QHBoxLayout>
#include <QMouseEvent>

namespace Shopper
{
	// SLabel a label that emits pressed() when clicked
	class SLabel: public QLabel
	{
		Q_OBJECT;			
	public:
		SLabel(QWidget * parent = 0, Qt::WindowFlags f = 0 );
		SLabel ( const QString & text, QWidget * parent = 0, Qt::WindowFlags f = 0 );
		void mouseReleaseEvent ( QMouseEvent * event );
		virtual void setVisible(bool vis);
	signals:
		void pressed();
	};
		
// LabelEntry - a label that turns into a textbox when clicked
	class LabelEntry : public QWidget
	{
		Q_OBJECT;			
	public:
		LabelEntry(QWidget *parent = 0);
		LabelEntry(const QString & label, QWidget *parent = 0);
	private:
		void init();  // real constructor
	public:
		QString getText();
		void setAlignment ( Qt::Alignment al );
		void setText ( const QString & d);
		virtual void setVisible(bool vis);
		void setFrameStyle(int i);
		void setSizePolicy(QSizePolicy::Policy h, QSizePolicy::Policy v);
		void setSizePolicy(QSizePolicy p);
		void setFont ( const QFont & );
		QLabel* label();
		
	protected:
		QString       data;
		SLabel        *myLabel;
		QLineEdit     *entry;
		QHBoxLayout   layout;

	public slots:
		void label_clicked();
		void entry_finished();
	signals:
		void changed();
	};
}
#endif // LABELENTRY_H
